bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDMoments.get_converter
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDMoments.get_converter